==> mdm-rpc-0.0.30-sources.jar: com/chinayanghe/msp/mdm/vo/org/OrgComplilationVo.java <==
package com.chinayanghe.msp.mdm.vo.org;


import java.io.Serializable;
import java.util.Date;

/**
 * 组织编制信息Vo
 * Created by danDy on 2017/5/8.
 */
public class OrgComplilationVo implements Serializable{
    private static final long serialVersionUID = 7615852678835645420L;
    //主键
    private String id;
    //组织编码
    private String orgCode;
    //岗位名称
    private  String positionName;
    //编制数
    private Integer complilationNumber;
    //岗位（职位）类别编码
    private String categoryCode;
    //岗位（职位）类别名称
    private String categoryName;
    //有效开始时间
    private Date validStartDate;
    //有效结束时间
    private Date validEndDate;
    //创建人
    private String createName;
    //更新人
    private String updateName;
    //创建岗位
    private String createPosition;
    //创建时间
    private Date createDate;
    //更改时间
    private Date updateDate;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getPositionName() {
        return positionName;
    }

    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    public Integer getComplilationNumber() {
        return complilationNumber;
    }

    public void setComplilationNumber(Integer complilationNumber) {
        this.complilationNumber = complilationNumber;
    }

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public Date getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(Date validStartDate) {
        this.validStartDate = validStartDate;
    }

    public Date getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(Date validEndDate) {
        this.validEndDate = validEndDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public String getCreatePosition() {
        return createPosition;
    }

    public void setCreatePosition(String createPosition) {
        this.createPosition = createPosition;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }


}

==> mdm-rpc-0.1.6-sources.jar: com/chinayanghe/msp/mdm/vo/org/OrgComplilationVo.java <==
package com.chinayanghe.msp.mdm.vo.org;


import java.util.Date;

/**
 * 组织编制信息Vo
 * Created by danDy on 2017/5/8.
 */
public class OrgComplilationVo {
    //主键
    private String id;
    //组织编码
    private String orgCode;
    //岗位名称
    private  String positionName;
    //编制数
    private Integer complilationNumber;
    //岗位（职位）类别编码
    private String categoryCode;
    //岗位（职位）类别名称
    private String categoryName;
    //有效开始时间
    private Date validStartDate;
    //有效结束时间
    private Date validEndDate;
    //创建人
    private String createName;
    //更新人
    private String updateName;
    //创建岗位
    private String createPosition;
    //创建时间
    private Date createDate;
    //更改时间
    private Date updateDate;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getPositionName() {
        return positionName;
    }

    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    public Integer getComplilationNumber() {
        return complilationNumber;
    }

    public void setComplilationNumber(Integer complilationNumber) {
        this.complilationNumber = complilationNumber;
    }

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public Date getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(Date validStartDate) {
        this.validStartDate = validStartDate;
    }

    public Date getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(Date validEndDate) {
        this.validEndDate = validEndDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public String getCreatePosition() {
        return createPosition;
    }

    public void setCreatePosition(String createPosition) {
        this.createPosition = createPosition;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }


}
